Savoir
=========


Description
-----------

Savoir is JsonRPC wrapper for Multichain
Its heavy based on [python-bitcoinrpc](https://github.com/jgarzik/python-bitcoinrpc)
but adapted for Multichain server, and replacing the httplib by
[requests](http://docs.python-requests.org/en/master/)

Installation
----------

Savoir can be installed from
[PyPi](https://pypi.python.org/pypi) using
[pip](https://pypi.python.org/pypi/pip). Enter the following command
into terminal:

    pip install savoir

Alternatively you can clone this public repository by entering the following
command into terminal.

    git clone https://github.com/dxmarkets/savoir

Usage
-------

Once you've download the code you should install needed libs

    sudo pip install -r requirements.txt

Finally just use the [multichain api documentacion](http://www.multichain.com/developers/json-rpc-api/) and make calls to the wrapper.
Remember to replace the rpc variables with the information of your specific chain

```python
import Savoir
rpcuser = 'multichainrpc'
rpcpasswd = 'YoUrLoNgRpCpAsSwOrD'
rpchost = 'localhost'
rpcport = '22335'
chainname = 'myChain'

api = Savoir(rpcuser, rpcpasswd, rpchost, rpcport, chainname)
api.getinfo()
```

License
-------

This package is distributed under BSD License.
See [LICENSE](https://github.com/DXMarkets/Savoir/blob/master/LICENSE)
